@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-             (C) 1999-2005 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999-2005 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "part.h"
@@ -31,20 +19,21 @@
 #include "guiactivateevent.h"
 #include "partmanager.h"
 
-#include <KXMLGUIFactory>
 #include <KIconLoader>
-
+#include <KXMLGUIFactory>
 
 using namespace KParts;
 
 Part::Part(QObject *parent)
-    : QObject(parent), PartBase(*new PartPrivate(this))
+    : QObject(parent)
+    , PartBase(*new PartPrivate(this))
 {
     PartBase::setPartObject(this);
 }
 
 Part::Part(PartPrivate &dd, QObject *parent)
-    : QObject(parent), PartBase(dd)
+    : QObject(parent)
+    , PartBase(dd)
 {
     PartBase::setPartObject(this);
 }
@@ -53,12 +42,11 @@ Part::~Part()
 {
     Q_D(Part);
 
-    //qCDebug(KPARTSLOG) << this;
+    // qCDebug(KPARTSLOG) << this;
 
     if (d->m_widget) {
         // We need to disconnect first, to avoid calling it !
-        disconnect(d->m_widget.data(), &QWidget::destroyed,
-                   this, &Part::slotWidgetDestroyed);
+        disconnect(d->m_widget.data(), &QWidget::destroyed, this, &Part::slotWidgetDestroyed);
     }
 
     if (d->m_manager) {
@@ -73,6 +61,7 @@ Part::~Part()
     delete d->m_iconLoader;
 }
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
 void Part::embed(QWidget *parentWidget)
 {
     if (widget()) {
@@ -81,6 +70,7 @@ void Part::embed(QWidget *parentWidget)
         widget()->show();
     }
 }
+#endif
 
 QWidget *Part::widget()
 {
@@ -101,6 +91,7 @@ void Part::setAutoDeletePart(bool autoDeletePart)
     d->m_autoDeletePart = autoDeletePart;
 }
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 82)
 KIconLoader *Part::iconLoader()
 {
     Q_D(Part);
@@ -110,6 +101,14 @@ KIconLoader *Part::iconLoader()
     }
     return d->m_iconLoader;
 }
+#endif
+
+KPluginMetaData Part::metaData() const
+{
+    Q_D(const Part);
+
+    return d->m_metaData;
+}
 
 void Part::setManager(PartManager *manager)
 {
@@ -140,8 +139,7 @@ void Part::setWidget(QWidget *widget)
 {
     Q_D(Part);
     d->m_widget = widget;
-    connect(d->m_widget.data(), &QWidget::destroyed,
-            this, &Part::slotWidgetDestroyed, Qt::UniqueConnection);
+    connect(d->m_widget.data(), &QWidget::destroyed, this, &Part::slotWidgetDestroyed, Qt::UniqueConnection);
 }
 
 #if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
@@ -216,9 +214,34 @@ void Part::slotWidgetDestroyed()
     }
 }
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 90)
 void Part::loadPlugins()
 {
-    PartBase::loadPlugins(this, this, componentData());
+    Q_D(Part);
+
+    PartBase::loadPlugins(this, this, d->m_metaData.pluginId());
+}
+#endif
+
+void Part::setMetaData(const KPluginMetaData &metaData)
+{
+    Q_D(Part);
+
+    d->m_metaData = metaData;
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    d->PartBasePrivate::setComponentData(KAboutData::fromPluginMetaData(metaData));
+
+    // backward-compatible registration, usage deprecated
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
+    KAboutData::registerPluginData(d->componentData());
+#endif
+    QT_WARNING_POP
+#endif
+
+    KXMLGUIClient::setComponentName(metaData.pluginId(), metaData.name());
 }
 
 #include "moc_part.cpp"
